@@ -38,6 +38,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 
@@ -76,7 +78,7 @@ class Dependable(metaclass=jsii.JSIIAbstractClass, jsii_type="constructs.Dependa
     def __init__(self) -> None:
         jsii.create(self.__class__, self, [])
 
-    @jsii.member(jsii_name="get") # type: ignore[misc]
+    @jsii.member(jsii_name="get")
     @builtins.classmethod
     def get(cls, instance: "IDependable") -> "Dependable":
         '''(deprecated) Return the matching Dependable for the given class instance.
@@ -87,9 +89,12 @@ class Dependable(metaclass=jsii.JSIIAbstractClass, jsii_type="constructs.Dependa
 
         :stability: deprecated
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Dependable.get)
+            check_type(argname="argument instance", value=instance, expected_type=type_hints["instance"])
         return typing.cast("Dependable", jsii.sinvoke(cls, "get", [instance]))
 
-    @jsii.member(jsii_name="implement") # type: ignore[misc]
+    @jsii.member(jsii_name="implement")
     @builtins.classmethod
     def implement(cls, instance: "IDependable", trait: "Dependable") -> None:
         '''(experimental) Turn any object into an IDependable.
@@ -99,9 +104,13 @@ class Dependable(metaclass=jsii.JSIIAbstractClass, jsii_type="constructs.Dependa
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Dependable.implement)
+            check_type(argname="argument instance", value=instance, expected_type=type_hints["instance"])
+            check_type(argname="argument trait", value=trait, expected_type=type_hints["trait"])
         return typing.cast(None, jsii.sinvoke(cls, "implement", [instance, trait]))
 
-    @jsii.member(jsii_name="of") # type: ignore[misc]
+    @jsii.member(jsii_name="of")
     @builtins.classmethod
     def of(cls, instance: "IDependable") -> "Dependable":
         '''(experimental) Return the matching Dependable for the given class instance.
@@ -110,9 +119,12 @@ class Dependable(metaclass=jsii.JSIIAbstractClass, jsii_type="constructs.Dependa
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Dependable.of)
+            check_type(argname="argument instance", value=instance, expected_type=type_hints["instance"])
         return typing.cast("Dependable", jsii.sinvoke(cls, "of", [instance]))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="dependencyRoots")
     @abc.abstractmethod
     def dependency_roots(self) -> typing.List["IConstruct"]:
@@ -127,7 +139,7 @@ class Dependable(metaclass=jsii.JSIIAbstractClass, jsii_type="constructs.Dependa
 
 
 class _DependableProxy(Dependable):
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="dependencyRoots")
     def dependency_roots(self) -> typing.List["IConstruct"]:
         '''(experimental) The set of constructs that form the root of this dependable.
@@ -233,6 +245,11 @@ class MetadataEntry:
         :param type: The metadata entry type.
         :param trace: Stack trace at the point of adding the metadata. Only available if ``addMetadata()`` is called with ``stackTrace: true``. Default: - no trace information
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(MetadataEntry.__init__)
+            check_type(argname="argument data", value=data, expected_type=type_hints["data"])
+            check_type(argname="argument type", value=type, expected_type=type_hints["type"])
+            check_type(argname="argument trace", value=trace, expected_type=type_hints["trace"])
         self._values: typing.Dict[str, typing.Any] = {
             "data": data,
             "type": type,
@@ -297,6 +314,10 @@ class MetadataOptions:
         :param stack_trace: Include stack trace with metadata entry. Default: false
         :param trace_from_function: A JavaScript function to begin tracing from. This option is ignored unless ``stackTrace`` is ``true``. Default: addMetadata()
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(MetadataOptions.__init__)
+            check_type(argname="argument stack_trace", value=stack_trace, expected_type=type_hints["stack_trace"])
+            check_type(argname="argument trace_from_function", value=trace_from_function, expected_type=type_hints["trace_from_function"])
         self._values: typing.Dict[str, typing.Any] = {}
         if stack_trace is not None:
             self._values["stack_trace"] = stack_trace
@@ -349,9 +370,14 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
         :param scope: -
         :param id: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Node.__init__)
+            check_type(argname="argument host", value=host, expected_type=type_hints["host"])
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         jsii.create(self.__class__, self, [host, scope, id])
 
-    @jsii.member(jsii_name="of") # type: ignore[misc]
+    @jsii.member(jsii_name="of")
     @builtins.classmethod
     def of(cls, construct: "IConstruct") -> "Node":
         '''(deprecated) Returns the node associated with a construct.
@@ -362,6 +388,9 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
 
         :stability: deprecated
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Node.of)
+            check_type(argname="argument construct", value=construct, expected_type=type_hints["construct"])
         return typing.cast("Node", jsii.sinvoke(cls, "of", [construct]))
 
     @jsii.member(jsii_name="addDependency")
@@ -372,6 +401,9 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
 
         :param deps: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Node.add_dependency)
+            check_type(argname="argument deps", value=deps, expected_type=typing.Tuple[type_hints["deps"], ...]) # pyright: ignore [reportGeneralTypeIssues]
         return typing.cast(None, jsii.invoke(self, "addDependency", [*deps]))
 
     @jsii.member(jsii_name="addMetadata")
@@ -394,6 +426,10 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
         :param stack_trace: Include stack trace with metadata entry. Default: false
         :param trace_from_function: A JavaScript function to begin tracing from. This option is ignored unless ``stackTrace`` is ``true``. Default: addMetadata()
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Node.add_metadata)
+            check_type(argname="argument type", value=type, expected_type=type_hints["type"])
+            check_type(argname="argument data", value=data, expected_type=type_hints["data"])
         options = MetadataOptions(
             stack_trace=stack_trace, trace_from_function=trace_from_function
         )
@@ -409,6 +445,9 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
 
         :param validation: The validation object.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Node.add_validation)
+            check_type(argname="argument validation", value=validation, expected_type=type_hints["validation"])
         return typing.cast(None, jsii.invoke(self, "addValidation", [validation]))
 
     @jsii.member(jsii_name="findAll")
@@ -420,6 +459,9 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
 
         :param order: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Node.find_all)
+            check_type(argname="argument order", value=order, expected_type=type_hints["order"])
         return typing.cast(typing.List["IConstruct"], jsii.invoke(self, "findAll", [order]))
 
     @jsii.member(jsii_name="findChild")
@@ -432,6 +474,9 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
 
         :return: Child with the given id.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Node.find_child)
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         return typing.cast("IConstruct", jsii.invoke(self, "findChild", [id]))
 
     @jsii.member(jsii_name="lock")
@@ -453,6 +498,10 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
         :param key: The context key.
         :param value: The context value.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Node.set_context)
+            check_type(argname="argument key", value=key, expected_type=type_hints["key"])
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         return typing.cast(None, jsii.invoke(self, "setContext", [key, value]))
 
     @jsii.member(jsii_name="tryFindChild")
@@ -463,6 +512,9 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
 
         :return: the child if found, or undefined
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Node.try_find_child)
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         return typing.cast(typing.Optional["IConstruct"], jsii.invoke(self, "tryFindChild", [id]))
 
     @jsii.member(jsii_name="tryGetContext")
@@ -475,6 +527,9 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
 
         :return: The context value or ``undefined`` if there is no context value for thie key.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Node.try_get_context)
+            check_type(argname="argument key", value=key, expected_type=type_hints["key"])
         return typing.cast(typing.Any, jsii.invoke(self, "tryGetContext", [key]))
 
     @jsii.member(jsii_name="tryRemoveChild")
@@ -487,6 +542,9 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Node.try_remove_child)
+            check_type(argname="argument child_name", value=child_name, expected_type=type_hints["child_name"])
         return typing.cast(builtins.bool, jsii.invoke(self, "tryRemoveChild", [child_name]))
 
     @jsii.member(jsii_name="validate")
@@ -503,13 +561,13 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
         '''
         return typing.cast(typing.List[builtins.str], jsii.invoke(self, "validate", []))
 
-    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.python.classproperty
     @jsii.member(jsii_name="PATH_SEP")
     def PATH_SEP(cls) -> builtins.str:
         '''Separator used to delimit construct path components.'''
         return typing.cast(builtins.str, jsii.sget(cls, "PATH_SEP"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="addr")
     def addr(self) -> builtins.str:
         '''Returns an opaque tree-unique address for this construct.
@@ -530,19 +588,19 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
         '''
         return typing.cast(builtins.str, jsii.get(self, "addr"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="children")
     def children(self) -> typing.List["IConstruct"]:
         '''All direct children of this construct.'''
         return typing.cast(typing.List["IConstruct"], jsii.get(self, "children"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="dependencies")
     def dependencies(self) -> typing.List["IConstruct"]:
         '''Return all dependencies registered on this node (non-recursive).'''
         return typing.cast(typing.List["IConstruct"], jsii.get(self, "dependencies"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="id")
     def id(self) -> builtins.str:
         '''The id of this construct within the current scope.
@@ -551,13 +609,13 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
         '''
         return typing.cast(builtins.str, jsii.get(self, "id"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="locked")
     def locked(self) -> builtins.bool:
         '''Returns true if this construct or the scopes in which it is defined are locked.'''
         return typing.cast(builtins.bool, jsii.get(self, "locked"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="metadata")
     def metadata(self) -> typing.List[MetadataEntry]:
         '''An immutable array of metadata objects associated with this construct.
@@ -566,7 +624,7 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
         '''
         return typing.cast(typing.List[MetadataEntry], jsii.get(self, "metadata"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="path")
     def path(self) -> builtins.str:
         '''The full, absolute path of this construct in the tree.
@@ -575,7 +633,7 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
         '''
         return typing.cast(builtins.str, jsii.get(self, "path"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="root")
     def root(self) -> "IConstruct":
         '''Returns the root of the construct tree.
@@ -584,7 +642,7 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
         '''
         return typing.cast("IConstruct", jsii.get(self, "root"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="scopes")
     def scopes(self) -> typing.List["IConstruct"]:
         '''All parent scopes of this construct.
@@ -597,7 +655,7 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
         '''
         return typing.cast(typing.List["IConstruct"], jsii.get(self, "scopes"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="scope")
     def scope(self) -> typing.Optional["IConstruct"]:
         '''Returns the scope in which this construct is defined.
@@ -606,7 +664,7 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
         '''
         return typing.cast(typing.Optional["IConstruct"], jsii.get(self, "scope"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="defaultChild")
     def default_child(self) -> typing.Optional["IConstruct"]:
         '''Returns the child construct that has the id ``Default`` or ``Resource"``.
@@ -630,6 +688,9 @@ class Node(metaclass=jsii.JSIIMeta, jsii_type="constructs.Node"):
 
     @default_child.setter
     def default_child(self, value: typing.Optional["IConstruct"]) -> None:
+        if __debug__:
+            type_hints = typing.get_type_hints(getattr(Node, "default_child").fset)
+            check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "defaultChild", value)
 
 
@@ -649,6 +710,9 @@ class DependencyGroup(metaclass=jsii.JSIIMeta, jsii_type="constructs.DependencyG
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(DependencyGroup.__init__)
+            check_type(argname="argument deps", value=deps, expected_type=typing.Tuple[type_hints["deps"], ...]) # pyright: ignore [reportGeneralTypeIssues]
         jsii.create(self.__class__, self, [*deps])
 
     @jsii.member(jsii_name="add")
@@ -659,6 +723,9 @@ class DependencyGroup(metaclass=jsii.JSIIMeta, jsii_type="constructs.DependencyG
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(DependencyGroup.add)
+            check_type(argname="argument scopes", value=scopes, expected_type=typing.Tuple[type_hints["scopes"], ...]) # pyright: ignore [reportGeneralTypeIssues]
         return typing.cast(None, jsii.invoke(self, "add", [*scopes]))
 
 
@@ -666,7 +733,7 @@ class DependencyGroup(metaclass=jsii.JSIIMeta, jsii_type="constructs.DependencyG
 class IConstruct(IDependable, typing_extensions.Protocol):
     '''Represents a construct.'''
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="node")
     def node(self) -> Node:
         '''The tree node.'''
@@ -674,13 +741,13 @@ class IConstruct(IDependable, typing_extensions.Protocol):
 
 
 class _IConstructProxy(
-    jsii.proxy_for(IDependable) # type: ignore[misc]
+    jsii.proxy_for(IDependable), # type: ignore[misc]
 ):
     '''Represents a construct.'''
 
     __jsii_type__: typing.ClassVar[str] = "constructs.IConstruct"
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="node")
     def node(self) -> Node:
         '''The tree node.'''
@@ -704,9 +771,13 @@ class Construct(metaclass=jsii.JSIIMeta, jsii_type="constructs.Construct"):
         :param scope: The scope in which to define this construct.
         :param id: The scoped construct ID. Must be unique amongst siblings. If the ID includes a path separator (``/``), then it will be replaced by double dash ``--``.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Construct.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         jsii.create(self.__class__, self, [scope, id])
 
-    @jsii.member(jsii_name="isConstruct") # type: ignore[misc]
+    @jsii.member(jsii_name="isConstruct")
     @builtins.classmethod
     def is_construct(cls, x: typing.Any) -> builtins.bool:
         '''Checks if ``x`` is a construct.
@@ -729,6 +800,9 @@ class Construct(metaclass=jsii.JSIIMeta, jsii_type="constructs.Construct"):
 
         :return: true if ``x`` is an object created from a class which extends ``Construct``.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Construct.is_construct)
+            check_type(argname="argument x", value=x, expected_type=type_hints["x"])
         return typing.cast(builtins.bool, jsii.sinvoke(cls, "isConstruct", [x]))
 
     @jsii.member(jsii_name="toString")
@@ -736,7 +810,7 @@ class Construct(metaclass=jsii.JSIIMeta, jsii_type="constructs.Construct"):
         '''Returns a string representation of this construct.'''
         return typing.cast(builtins.str, jsii.invoke(self, "toString", []))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="node")
     def node(self) -> Node:
         '''The tree node.'''
